/****************************************************************************
 *
 * pshinter.c
 *
 *   FreeType PostScript Hinting module
 *
 * Copyright (C) 2001-2026 by
 * David Turner, Robert Wilhelm, and Werner Lemberg.
 *
 * This file is part of the FreeType project, and may only be used,
 * modified, and distributed under the terms of the FreeType project
 * license, LICENSE.TXT.  By continuing to use, modify, or distribute
 * this file you indicate that you have read the license and
 * understand and accept it fully.
 *
 */


#define FT_MAKE_OPTION_SINGLE_OBJECT

#include "pshalgo.c"
#include "pshglob.c"
#include "pshmod.c"
#include "pshrec.c"


/* END */
